@@ -32,4 +32,4 @@ art_rect_list_from_uta (ArtUta *uta, int max_width, int max_height,
 }
 #endif /* __cplusplus */
 
-#endif /* __ART_UTA_RECT_H__ */
+#endif /* __ART_RECT_UTA_H__ */
